"summary.fitCoinertia" <-
function(object, ...)
  {
    class(object) <- "summary.fitCoinertia"
    object
  }

